@@ -40,6 +40,12 @@ class StackingRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
                        regressor being fitted
         - `verbose>2`: Changes `verbose` param of the underlying regressor to
            self.verbose - 2
+    store_train_meta_features : bool (default: False)
+        If True, the meta-features computed from the training data
+        used for fitting the
+        meta-regressor stored in the `self.train_meta_features_` array,
+        which can be
+        accessed after calling `fit`.
 
     Attributes
     ----------
@@ -51,9 +57,14 @@ class StackingRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
         Model coefficients of the fitted meta-estimator
     intercept_ : float
         Intercept of the fitted meta-estimator
+    train_meta_features : numpy array, shape = [n_samples, len(self.regressors)]
+        meta-features for training data, where n_samples is the
+        number of samples
+        in training data and len(self.regressors) is the number of regressors.
 
     """
-    def __init__(self, regressors, meta_regressor, verbose=0):
+    def __init__(self, regressors, meta_regressor, verbose=0,
+                 store_train_meta_features=False):
 
         self.regressors = regressors
         self.meta_regressor = meta_regressor
@@ -64,6 +75,7 @@ class StackingRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
                                      key, value in
                                      _name_estimators([meta_regressor])}
         self.verbose = verbose
+        self.store_train_meta_features = store_train_meta_features
 
     def fit(self, X, y):
         """Learn weight coefficients from training data for each regressor.
@@ -102,8 +114,12 @@ class StackingRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
 
             regr.fit(X, y)
 
-        meta_features = self._predict_meta_features(X)
+        meta_features = self.predict_meta_features(X)
         self.meta_regr_.fit(meta_features, y)
+
+        # save meta-features for training data
+        if self.store_train_meta_features:
+            self.train_meta_features_ = meta_features
         return self
 
     @property
@@ -135,7 +151,23 @@ class StackingRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
 
             return out
 
-    def _predict_meta_features(self, X):
+    def predict_meta_features(self, X):
+        """ Get meta-features of test-data.
+
+        Parameters
+        ----------
+        X : numpy array, shape = [n_samples, n_features]
+            Test vectors, where n_samples is the number of samples and
+            n_features is the number of features.
+
+        Returns
+        -------
+        meta-features : numpy array, shape = [n_samples, len(self.regressors)]
+            meta-features for test data, where n_samples is the number of
+            samples in test data and len(self.regressors) is the number
+            of regressors.
+
+        """
         return np.column_stack([r.predict(X) for r in self.regr_])
 
     def predict(self, X):
@@ -152,5 +184,5 @@ class StackingRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
         y_target : array-like, shape = [n_samples] or [n_samples, n_targets]
             Predicted target values.
         """
-        meta_features = self._predict_meta_features(X)
+        meta_features = self.predict_meta_features(X)
         return self.meta_regr_.predict(meta_features)
